@@ -9,6 +9,7 @@ def on_start():
     ctrl.training_reset = engine.training_reset
 
     ctrl.prediction_update = engine.prediction_update
-    ctrl.prediction_next_failure = engine.prediction_next_failure
 
     ctrl.xai_run = engine.xai_run
+
+    ctrl.testing_run = engine.testing_run
