@@ -3,8 +3,8 @@ from .main import (
     training_add,
     training_reset,
     prediction_update,
-    prediction_next_failure,
     xai_run,
+    testing_run,
 )
 
 __all__ = [
@@ -12,6 +12,6 @@ __all__ = [
     "training_add",
     "training_reset",
     "prediction_update",
-    "prediction_next_failure",
     "xai_run",
+    "testing_run",
 ]
