@@ -2,6 +2,7 @@ from .common import has_trained_model, delete_model, DATA_DIR
 from .training import training_add
 from .prediction import prediction_reload, prediction_update, prediction_xai_params
 from .xai import xai_update, SALIENCY_TYPES
+from .testing import testing_run
 
 __all__ = [
     "DATA_DIR",
@@ -13,4 +14,5 @@ __all__ = [
     "prediction_xai_params",
     "xai_update",
     "SALIENCY_TYPES",
+    "testing_run",
 ]
